
#*    dsgui - a graphical user interface for Datove schranky
#*    Copyright (C) 2009-2010  CZ.NIC, z.s.p.o. (http://www.nic.cz)
#*
#*    This library is free software; you can redistribute it and/or
#*    modify it under the terms of the GNU Library General Public
#*    License as published by the Free Software Foundation; either
#*    version 2 of the License, or (at your option) any later version.
#*
#*    This library is distributed in the hope that it will be useful,
#*    but WITHOUT ANY WARRANTY; without even the implied warranty of
#*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#*    Library General Public License for more details.
#*
#*    You should have received a copy of the GNU Library General Public
#*    License along with this library; if not, write to the Free
#*    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

"""
class Credentials for storage of account related info resides here
"""

import datetime

class Credentials(object):
  """stores credentials to an account"""
  
  def __init__(self, username, password, test_account=False):
    self.username = username
    self.password = password
    self.test_account = test_account
    
  def __str__(self):
    return "%s:%s" % (self.username, self.test_account) 
    
  def change_password(self, new_password):
    """returns true if password was really changed"""
    if new_password == self.password:
      return False
    else:
      self.password = new_password
      return True
    
  def get_id(self):
    return (self.username, self.test_account)
    
    
class Account(object):
  """stores info about an account"""
  
  def __init__(self, credentials):
    self.credentials = credentials
    self.account_info = None
    self.password_expiration_date = None
    
  def __str__(self):
    acc_type = self.credentials.test_account and "Test" or "Normal"
    return "Account '%s' - %s" % (self.credentials.username, acc_type)
    
  def is_password_expiring(self, tolerance=5):
    """tolerance is in days or a datetime.timedelta"""
    if type(tolerance) == int:
      tolerance = datetime.timedelta(days=tolerance)
    if self.password_expiration_date:
      return self.password_expiration_date < datetime.datetime.now() + tolerance
    else:
      return None
    
  def has_password_expired(self):
    return self.is_password_expiring(0)
    
  def get_password_expiration_delta(self):
    return self.password_expiration_date - datetime.datetime.now()

